==> api-common-server-0.1.9.jar: externs/custom.js <==
var deasyncExterns = {"loopWhile": function(f) {}};

var NodeRSAExterns = {"generateKeyPair": function(a,b){}};

var CryptoExterns = {"randomBytes": function(a){},
                     "createCipheriv": {"update": function(a,b,c) {},
                                        "final": function(a) {}},
                     "createDecipheriv":  {"update": function(a,b,c) {},
                                           "final": function(a) {}},
                     "constants": {"RSA_PKCS1_PADDING": {}},
                     "publicEncrypt": function(a,b){},
                     "privateEncrypt": function(a,b){},
                     "publicDecrypt": function(a,b){},
                     "privateDecrypt": function(a,b){}};

var zlibExterns = {"gzip": function(a,c){},
                   "unzip": function(a,c){}};

var redisExterns = {"createClient": {"set": function(k,v,c){},
                                     "get": function(k,c){},
                                     "del": function(k,c){},
                                     "keys": function(k,c){},
                                     "sadd": function(k,v,c){},
                                     "smembers": function(k,c){},
                                     "srem": function(k,v,c){},
                                     "expire": function(k, s, c){},
                                     "flushall": function(c){}}};

var googleapisExterns = {"auth": {"OAuth2":{"generateAuthUrl": function(a){},
                                            "getToken": function(a,c){},
                                            "setCredentials": function(a){}}},
                         "plus": {"people": {"get": function(a,c){}}}};

var CloudWatchExterns = {"putMetricData": function(a,c) {}};

var AWSXRayExterns = {"captureAWS": function(e) {},
                      "captureFunc": function(n, c) {},
                      "getSegment": function() {},
                      "setAWSWhitelist": function(e) {},
                      "captureAsyncFunc": function(n, c) {},
                      "captureHTTPs": function(m) {}};

var SubSegmentExterns = {"addAnnotation": function(k,v) {},
                         "addMetadata": function(k, v, ns) {},
                         "addAttribute": function(n, v) {},
                         "addIncomingRequestData": function(data) {},
                         "setServiceData": function(data) {},
                         "close": function(s) {},
                         "addRemoteRequestData": function(s, b, c) {},
                         "addError": function(e, r) {},
                         "addErrorFlag": function(e) {},
                         "addNewSubsegment": function(name) {},
                         "addThrottleFlag": function(e) {},
                         "addFaultFlag": function(e) {}};
var ContextUtilsExterns = {"resolveSegment": function(o) {},
                           "setSegment": function(s) {},
                           "resolveManualSegmentParams": function(o) {},
                           "getNamespace": {"run": function(f){}}};

==> api-common-server-0.1.33.jar: externs/custom.js <==
var deasyncExterns = {"loopWhile": function(f) {}};

var NodeRSAExterns = {"generateKeyPair": function(a,b){}};

var CryptoExterns = {"randomBytes": function(a){},
                     "createCipheriv": {"update": function(a,b,c) {},
                                        "final": function(a) {}},
                     "createDecipheriv":  {"update": function(a,b,c) {},
                                           "final": function(a) {}},
                     "constants": {"RSA_PKCS1_PADDING": {}},
                     "publicEncrypt": function(a,b){},
                     "privateEncrypt": function(a,b){},
                     "publicDecrypt": function(a,b){},
                     "privateDecrypt": function(a,b){}};

var zlibExterns = {"gzip": function(a,c){},
                   "unzip": function(a,c){},
		   "gzipSync": function(a){},
		   "unzipSync": function(a){}};

var redisExterns = {"createClient": {"set": function(k,v,c){},
                                     "get": function(k,c){},
                                     "del": function(k,c){},
                                     "keys": function(k,c){},
                                     "sadd": function(k,v,c){},
                                     "smembers": function(k,c){},
                                     "srem": function(k,v,c){},
                                     "expire": function(k, s, c){},
                                     "flushall": function(c){}}};

var googleapisExterns = {"auth": {"OAuth2":{"generateAuthUrl": function(a){},
                                            "getToken": function(a,c){},
                                            "setCredentials": function(a){}}},
                         "plus": {"people": {"get": function(a,c){}}}};

var CloudWatchExterns = {"putMetricData": function(a,c) {}};

var AWSXRayExterns = {"captureAWS": function(e) {},
                      "captureFunc": function(n, c) {},
                      "getSegment": function() {},
                      "setAWSWhitelist": function(e) {},
                      "captureAsyncFunc": function(n, c) {},
                      "captureHTTPs": function(m) {}};

var SubSegmentExterns = {"addAnnotation": function(k,v) {},
                         "addMetadata": function(k, v, ns) {},
                         "addAttribute": function(n, v) {},
                         "addIncomingRequestData": function(data) {},
                         "setServiceData": function(data) {},
                         "close": function(s) {},
                         "addRemoteRequestData": function(s, b, c) {},
                         "addError": function(e, r) {},
                         "addErrorFlag": function(e) {},
                         "addNewSubsegment": function(name) {},
                         "addThrottleFlag": function(e) {},
                         "addFaultFlag": function(e) {}};
var ContextUtilsExterns = {"resolveSegment": function(o) {},
                           "setSegment": function(s) {},
                           "resolveManualSegmentParams": function(o) {},
                           "getNamespace": {"run": function(f){}}};
